@@ -18,13 +18,9 @@
 
 #include <stdarg.h>
 
-#include <glib/gi18n.h>
-
 #include "gom-filter.h"
 #include "gom-resource.h"
 
-G_DEFINE_TYPE(GomFilter, gom_filter, G_TYPE_INITIALLY_UNOWNED)
-
 struct _GomFilterPrivate
 {
    GomFilterMode mode;
@@ -39,6 +35,8 @@ struct _GomFilterPrivate
    GQueue *subfilters;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(GomFilter, gom_filter, G_TYPE_INITIALLY_UNOWNED)
+
 enum
 {
    PROP_0,
@@ -698,12 +696,11 @@ gom_filter_class_init (GomFilterClass *klass)
    object_class->finalize = gom_filter_finalize;
    object_class->get_property = gom_filter_get_property;
    object_class->set_property = gom_filter_set_property;
-   g_type_class_add_private(object_class, sizeof(GomFilterPrivate));
 
    gParamSpecs[PROP_MODE] =
       g_param_spec_enum("mode",
-                        _("Mode"),
-                        _("The mode of the filter."),
+                        "Mode",
+                        "The mode of the filter.",
                         GOM_TYPE_FILTER_MODE,
                         GOM_FILTER_SQL,
                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
@@ -712,8 +709,8 @@ gom_filter_class_init (GomFilterClass *klass)
 
    gParamSpecs[PROP_SQL] =
       g_param_spec_string("sql",
-                          _("SQL"),
-                          _("The SQL for the filter."),
+                          "SQL",
+                          "The SQL for the filter.",
                           NULL,
                           G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
    g_object_class_install_property(object_class, PROP_SQL,
@@ -729,10 +726,7 @@ gom_filter_class_init (GomFilterClass *klass)
 static void
 gom_filter_init (GomFilter *filter)
 {
-   filter->priv =
-      G_TYPE_INSTANCE_GET_PRIVATE(filter,
-                                  GOM_TYPE_FILTER,
-                                  GomFilterPrivate);
+   filter->priv = gom_filter_get_instance_private(filter);
    filter->priv->mode = GOM_FILTER_SQL;
 }
 
